@@ -1,16 +1,19 @@
 
+#include <R.h>
+#include <R_ext/Lapack.h>
+
+#include <Rinternals.h>
+
 #include <math.h>
 #include <stdio.h>
 #include <time.h>
 
-#include <R.h>
-#include <R_ext/Lapack.h>
 /*
 #include "mkl_lapack.h"
 #include "mkl_blas.h"
 */
 
-#ifdef _MKL_LAPACK_H_
+#ifdef _MKL_LAPACK_H_ 
     #define CTOF(x) x
 #else
     #define CTOF(x) x ## _
@@ -108,8 +111,7 @@ double VectorVectorDot( double* x, double* y, int* n )
 
 /*****************************************************************************/
 
-void MatrixMatrixDiagSolve( double* D, double* A, double* res, int* rows, int*
-cols )
+void MatrixMatrixDiagSolve( double* D, double* A, double* res, int* rows, int* cols )
 {
     int i,j;
     int n = (*rows);
@@ -124,11 +126,10 @@ cols )
 
 /*****************************************************************************/
 
-void MatrixVectorMult( double* alpha, double* A, int trans, double* x, double*
-beta, double* b, int* rows, int* cols )
+void MatrixVectorMult( double* alpha, double* A, int* trans, double* x, double* beta, double* b, int* rows, int* cols )
 {
     int one=1;
-    if (trans)
+    if ((*trans))
     {
         CTOF(dgemv)("T", rows, cols, alpha, A, rows, x, &one, beta, b, &one );
         /* dgemv('T', *rows, *cols, *alpha, A, *rows, x, one, *beta, b, one ); */
@@ -142,10 +143,10 @@ beta, double* b, int* rows, int* cols )
 
 /*****************************************************************************/
 
-void MatrixConstantPlusDiag( double* A, double c, int* n )
+void MatrixConstantPlusDiag( double* A, double * c, int* n )
 {
     int i;
-    for (i=0;i<(*n);i++) A[i+i*(*n)] += c;
+    for (i=0;i<(*n);i++) A[i+i*(*n)] += (*c);
 }
 
 /*****************************************************************************/
@@ -177,7 +178,6 @@ void MatrixLUFactorize( double* A, int* n, int* ipiv, int* info )
 void MatrixLUSolve( double* A, int* n, int* ipiv, double* rhs, int *nrhs )
 {
     int info = 0;
-    int one  = 1;
     CTOF(dgetrs)("N", n, nrhs, A, n, ipiv, rhs, n, &info );
     /* dgetrs('N', *n, *nrhs, A, *n, ipiv, rhs, *n, &info ); */
 }
@@ -228,22 +228,20 @@ void MatrixMatrixPlusEquals( double* x, double* res, int* rows, int* cols)
 
 /*****************************************************************************/
 
-void MatrixConstantSet( double* A, double c, int* rows, int* cols)
+void MatrixConstantSet( double* A, double* c, int* rows, int* cols)
 {
     int i;
     int len = (*rows)*(*cols);
-    for (i=0;i<len;i++) A[i] = c;
+    for (i=0;i<len;i++) A[i] = (*c);
 }
 
 /*****************************************************************************/
 
-void MatrixMatrixMult( double *alpha, double* A, int transA, double* B,
-    int transB, double* beta, double* C, int* rA, int *cA, int *rB, int *cB,
-    int* rC, int* cC  )
+void MatrixMatrixMult( double *alpha, double* A, int* transA, double* B, int* transB, double* beta, double* C, int* rA, int *cA, int *rB, int *cB, int* rC, int* cC  )
 {
-    if (transA)
+    if ((*transA))
     {
-        if (transB)
+        if ((*transB))
         {
             CTOF(dgemm)( "T", "T", rC, cC, cB, alpha, A, rA, B, rB, beta, C, rC );
             /* dgemm( 'T', 'T', *rC, *cC, *cB, *alpha, A, *rA, B, *rB, *beta, C, *rC ); */
@@ -256,7 +254,7 @@ void MatrixMatrixMult( double *alpha, double* A, int transA, double* B,
     }
     else
     {
-        if (transB)
+        if ((*transB))
         {
             CTOF(dgemm)( "N", "T", rC, cC, cA, alpha, A, rA, B, rB, beta, C, rC );
             /* dgemm( 'N', 'T', *rC, *cC, *cA, *alpha, A, *rA, B, *rB, *beta, C, *rC ); */
@@ -285,11 +283,14 @@ void LRQPInitPoint( int *n, int *m, int *p, double *Q, double *c, double *A,
     int i;
     double pone =  1.0;
     double mone = -1.0;
-    double zero =  0.0;
+    int intzero = 0;
+    int intone = 1;
+    double realzero =  0.0;
+    
     for (i=0;i<(*n);i++) alpha[i] = MIN(EPSINIT,u[i]*EPSINIT);
     for (i=0;i<(*p);i++) beta[i]  = 0.0;
-    MatrixVectorMult( &pone, Q, 1, alpha, &zero, w, n, m );
-    if ( (*n)!=(*m) ) MatrixVectorMult( &mone, Q, 0, w, &zero, temp, n, m );
+    MatrixVectorMult( &pone, Q, &intone, alpha, &realzero, w, n, m );
+    if ( (*n)!=(*m) ) MatrixVectorMult( &mone, Q, &intzero, w, &realzero, temp, n, m );
     else              for (i=0;i<(*n);i++) temp[i] += -w[i];
     VectorVectorMult( &mone, c, temp, n );
     for (i=0;i<(*n);i++)
@@ -341,14 +342,16 @@ void LRQPCalcStats( int *n, int *m, int *p, double *Q, double *c, double *A,
     double pone =  1.0;
     double mone = -1.0;
     double zero =  0.0;
-    MatrixVectorMult( &pone, Q, 1, alpha, &zero, w, n, m );
+    int intone = 1;
+    int intzero = 0;
+    MatrixVectorMult( &pone, Q, &intone, alpha, &zero, w, n, m );
     VectorVectorMinus( u, alpha, UminusAlpha, n );
     VectorVectorDivide( xi, UminusAlpha, XiOnUminusAlpha, n );
     VectorVectorDivide( zeta, alpha, ZetaOnAlpha, n );
     if ( (*n)==(*m) )
     {   
-        if (*p) MatrixVectorMult( &mone, A, 0, beta, &zero, r1, n, p );
-        else    MatrixConstantSet( r1, 0.0, n, &one );
+        if (*p) MatrixVectorMult( &mone, A, &intzero, beta, &zero, r1, n, p );
+        else    MatrixConstantSet( r1, &zero, n, &one );
         VectorVectorMult( &mone, w,  r1, n );
         VectorVectorMult( &mone, c,  r1, n );
         VectorVectorMult( &mone, xi, r1, n );
@@ -357,9 +360,9 @@ void LRQPCalcStats( int *n, int *m, int *p, double *Q, double *c, double *A,
     }
     else
     {
-        if (*p) MatrixVectorMult( &mone, A, 0, beta, &zero, r1, n, p );
-        else    MatrixConstantSet( r1, 0.0, n, &one );
-        MatrixVectorMult( &mone, Q, 0, w, &pone, r1, n, m );
+        if (*p) MatrixVectorMult( &mone, A, &intzero, beta, &zero, r1, n, p );
+        else    MatrixConstantSet( r1, &zero, n, &one );
+        MatrixVectorMult( &mone, Q, &intzero, w, &pone, r1, n, m );
         VectorVectorMult( &mone, c,  r1, n );
         VectorVectorMult( &mone, xi, r1, n );
         VectorVectorMult( &pone, zeta, r1, n );
@@ -368,7 +371,7 @@ void LRQPCalcStats( int *n, int *m, int *p, double *Q, double *c, double *A,
     if (*p)
     {
         VectorVectorCopy( r2, b, p );
-        MatrixVectorMult( &mone, A, 1, alpha, &pone, r2, n, p );
+        MatrixVectorMult( &mone, A, &intone, alpha, &pone, r2, n, p );
         *dual = VectorAbsSum( r2, p );
     }
     *prim   = VectorAbsSum( r1, n );
@@ -376,42 +379,40 @@ void LRQPCalcStats( int *n, int *m, int *p, double *Q, double *c, double *A,
     cTalpha = VectorVectorDot( c, alpha, n );
     if (*p) *gap = fabs( quad + cTalpha + VectorVectorDot( u, xi, n ) + VectorVectorDot( b, beta, p ) );
     else    *gap = fabs( quad + cTalpha + VectorVectorDot( u, xi, n ) );
-    *term   = *comp / ( fabs( 0.5*quad + cTalpha) + 1.0);
-    temp    = (1.0 - *mult + EPSIPM)/(10.0 + *mult);
-    *t      = *comp*(temp*temp)/(2*(*n));
+    *term   = (*comp) / ( fabs( 0.5*quad + cTalpha) + 1.0);
+    temp    = (1.0 - (*mult) + EPSIPM)/(10.0 + *mult);
+    *t      = (*comp)*(temp*temp)/(2*(*n));
     for (i=0;i<(*n);i++) D[i] = XiOnUminusAlpha[i] + ZetaOnAlpha[i] + EPSPERT;
 }
 
 /*****************************************************************************/
 
-void LRQPDisplay( int i, double *prim, double *dual, double *comp, double *gap,
-                  double *term )
+void LRQPDisplay(int *i, double *prim, double *dual, double *comp, double *gap, double *term )
 {
-    Rprintf("%3d %15.7e %15.7e %15.7e %15.7e %15.7e \n", i, *prim, *dual, *comp, *gap, *term );
+    Rprintf("%3d %15.7e %15.7e %15.7e %15.7e %15.7e \n", ((*i) + 1), *prim, *dual, *comp, *gap, *term );
 }
 
 /*****************************************************************************/
 
-void LRQPSummary( int i, int niter, int method, int n, int m, double *prim, 
-    double *dual, double *comp, double *gap, double *term )
+void LRQPSummary(int *i, int *niter, int *method, int *n, int *m, double *prim, double *dual, double *comp, double *gap, double *term)
 {
-    if (i==niter)
+    if ((*i)==(*niter))
     {
         Rprintf("LowRankQP FAILED TO CONVERGE\n");
-        if (n==m)
+        if ((*n)==(*m))
         {
-            if (method==CHOL) Rprintf("    Try increasing niter, using method=LU, or rescaling problem.\n");
-            else              Rprintf("    Try increasing niter, or rescaling problem.\n");
+            if ((*method)==CHOL) Rprintf("    Try increasing niter, using method=LU, or rescaling problem.\n");
+            else                 Rprintf("    Try increasing niter, or rescaling problem.\n");
         }
         else
         {
-            if (method==SMW)  Rprintf("    Try increasing niter, using method=PFCF, using method=LU, or rescaling problem.\n");
-            else              Rprintf("    Try increasing niter, or rescaling problem.\n");
+            if ((*method)==SMW)  Rprintf("    Try increasing niter, using method=PFCF, using method=LU, or rescaling problem.\n");
+            else                 Rprintf("    Try increasing niter, or rescaling problem.\n");
         }
     }
     else
     {
-        Rprintf("LowRankQP CONVERGED IN %d ITERATIONS\n\n", i+1 );
+        Rprintf("LowRankQP CONVERGED IN %d ITERATIONS\n\n", (*i)+1 );
         Rprintf("    Primal Feasibility    = %15.7e\n", *prim);
         Rprintf("    Dual Feasibility      = %15.7e\n", *dual);
         Rprintf("    Complementarity Value = %15.7e\n", *comp);
@@ -422,12 +423,12 @@ void LRQPSummary( int i, int niter, int method, int n, int m, double *prim,
 
 /****************************************************************************/
 
-void PfcfSolve( int *n, double *p, double *beta, double *r, int trans )
+void PfcfSolve( int *n, double *p, double *beta, double *r, int *trans)
 {
     int j;
     double sigma;
     int nm1 = (*n)-1;
-    if (trans)
+    if ((*trans))
     {
         sigma = r[nm1]*p[nm1];
         for (j=(nm1-1);j>0;j--)
@@ -454,22 +455,19 @@ void PfcfSolve( int *n, double *p, double *beta, double *r, int trans )
 void PfcfFactorize( int *n, int *m, double *Q, double *D, double *P,
     double *Beta, double *Lambda, double *LambdaTemp, double *t  )
 {
-    int i, j, k;
+    int i, j;
     double infinity = 1.0e12;
     double epsilon  = 1.0e-12;
     double temp;
-
-    int one = 1;
-
     int ind;
-    int indi;
-    int indj;
-
+    
+    int zero = 0;
+  
     VectorVectorCopy( LambdaTemp, D, n );
     MatrixMatrixCopy( P, Q, n, m );
     for (i=0;i<(*m);i++)
     {
-        for (j=0;j<i;j++) PfcfSolve( n, P+j*(*n), Beta+j*(*n), P+i*(*n), 0 );
+        for (j=0;j<i;j++) PfcfSolve( n, P+j*(*n), Beta+j*(*n), P+i*(*n), &zero );
         t[0] = 1.0;
         for (j=0;j<(*n);j++)
         {
@@ -518,27 +516,35 @@ void LRQPFactorize( int *n, int *m, int *method, double *Q, double *D,
 {
     int    info =  0;
     double pone =  1.0;
-    double mone = -1.0;
     double zero =  0.0;
+    
+    int intone = 1;
+    int intzero = 0;
+    
+    int lu = 1;
+    int chol = 2;
+    int smw = 3;
+    int pfcf = 4;
+    
 
-    if ((*method==LU)||(*method==CHOL))
+    if (((*method)==lu)||((*method)==chol))
     {
         if ((*n)==(*m)) MatrixMatrixCopy( M, Q, n, n );
-        else            MatrixMatrixMult( &pone, Q, 0, Q, 1, &zero, M, n, m, n, m, n, n );
+        else            MatrixMatrixMult( &pone, Q, &intzero, Q, &intone, &zero, M, n, m, n, m, n, n );
         MatrixMatrixPlusDiag( M, D, n );
-        if (*method==LU)        MatrixLUFactorize( M, n, pivN, &info );
-        else if (*method==CHOL) MatrixCholFactorize( M, n, &info );
+        if ((*method)==lu)        MatrixLUFactorize( M, n, pivN, &info );
+        else if ((*method)==chol) MatrixCholFactorize( M, n, &info );
     }
     else
     {
-        if (*method==SMW)
+        if ((*method)==smw)
         {
             MatrixMatrixDiagSolve( D, Q, buffNxM, n, m );
-            MatrixMatrixMult( &pone, Q, 1, buffNxM, 0, &zero, M, n, m, n, m, m, m );
-            MatrixConstantPlusDiag( M, pone, m );
+            MatrixMatrixMult( &pone, Q, &intone, buffNxM, &intzero, &zero, M, n, m, n, m, m, m );
+            MatrixConstantPlusDiag( M, &pone, m );
             MatrixCholFactorize( M, m, &info );
         }
-        else if (*method==PFCF)
+        else if ((*method)==pfcf)
         {
             PfcfFactorize( n, m, Q, D, P, Beta, Lambda, LambdaTemp, T );
         }
@@ -571,40 +577,42 @@ void LRQPSolve( int *n, int *m, int *nrhs, int *method, double *Q, double *D,
 {
     int i, j;
     int info    = 0;
-    int one     = 1;
+    int intone  = 1;
+    int intzero = 0;
     double pone =  1.0;
     double mone = -1.0;
     double zero =  0.0;
-
     
-    long int start;
-    long int finish;
+    int lu = 1;
+    int chol = 2;
+    int smw = 3;
+    int pfcf = 4;
 
     MatrixMatrixCopy( sol, rhs, n, nrhs );
-    if (*method==LU)
+    if ((*method)==lu)
     {
         MatrixLUSolve( M, n, pivN, sol, nrhs );
     }
-    else if (*method==CHOL)
+    else if ((*method)==chol)
     {
         MatrixCholSolve( M, n, sol, nrhs, &info );
     }
-    else if (*method==SMW)
+    else if ((*method)==smw)
     {
         MatrixMatrixDiagSolve( D, sol, sol, n, nrhs );
-        MatrixMatrixMult( &pone, Q, 1, sol, 0, &zero, buffMxP, n, m, n, nrhs, m, nrhs );
+        MatrixMatrixMult( &pone, Q, &intone, sol, &intzero, &zero, buffMxP, n, m, n, nrhs, m, nrhs );
         MatrixCholSolve( M, m, buffMxP, nrhs, &info );
-        MatrixMatrixMult( &mone, Q, 0, buffMxP, 0, &zero, sol, n, m, m, nrhs, n,nrhs );
+        MatrixMatrixMult( &mone, Q, &intzero, buffMxP, &intzero, &zero, sol, n, m, m, nrhs, n,nrhs );
         MatrixMatrixPlus( sol, rhs, sol, n, nrhs );
         MatrixMatrixDiagSolve( D, sol, sol, n, nrhs );
     }
-    else if (*method==PFCF)
+    else if ((*method)==pfcf)
     {
         for (i=0;i<(*nrhs);i++)
         {
-            for (j=0;j<(*m);j++) PfcfSolve( n, P+(j*(*n)), Beta+(j*(*n)), sol+(i*(*n)), 0);
-            MatrixMatrixDiagSolve( Lambda, sol+(i*(*n)), sol+(i*(*n)), n, &one );
-            for (j=((*m)-1);j>=0;j--) PfcfSolve( n, P+(j*(*n)), Beta+(j*(*n)),sol+(i*(*n)), 1);
+            for (j=0;j<(*m);j++) PfcfSolve( n, P+(j*(*n)), Beta+(j*(*n)), sol+(i*(*n)), &intzero);
+            MatrixMatrixDiagSolve( Lambda, sol+(i*(*n)), sol+(i*(*n)), n, &intone );
+            for (j=((*m)-1);j>=0;j--) PfcfSolve( n, P+(j*(*n)), Beta+(j*(*n)),sol+(i*(*n)), &intone);
         }
     }
 }
@@ -632,16 +640,21 @@ void LRQPCalcDx( int *n, int *m, int *p, int *method, double *Q, double *c,
     double *buffMxP, double *buffMx1, double* buffPxP, double *buffPx1,
     int *pivN, double *R, double *r, double *r1, double* r2, double *r3,
     double *r4, double* r5, double *D, double *M, double *t, double *P,
-    double *Beta, double *Lambda, double *LambdaTemp, double *T, int predcorr)
+    double *Beta, double *Lambda, double *LambdaTemp, double *T, int *predcorr)
 {
 
-    int i, j;
+    int i;
     int    info = 0;
-    int    one  = 1;
+    int    intone  = 1;
+    int    intzero = 0;
     double pone =  1.0;
     double mone = -1.0;
     double zero =  0.0;
-    if ((predcorr==PRED)&&(*p))
+    
+    int pred = 1;
+    int corr = 2;
+    
+    if (((*predcorr)==pred)&&(*p))
     {
         LRQPSolve( n, m, p, method, Q, D, A, R, M, pivN, buffMxP, P, Beta, Lambda );
     }
@@ -650,28 +663,28 @@ void LRQPCalcDx( int *n, int *m, int *p, int *method, double *Q, double *c,
         r3[i] = - zeta[i];
         r4[i] = - xi[i];
     }
-    if (predcorr==CORR)
+    if ((*predcorr)==corr)
     {
-        for (i=0;i<(*n);i++) r3[i] += ( *t - (dalpha[i] * dzeta[i]) )/alpha[i];
-        for (i=0;i<(*n);i++) r4[i] += ( *t + (dalpha[i] * dxi[i]) )/UminusAlpha[i];
+        for (i=0;i<(*n);i++) r3[i] += ( (*t) - (dalpha[i] * dzeta[i]) )/alpha[i];
+        for (i=0;i<(*n);i++) r4[i] += ( (*t) + (dalpha[i] * dxi[i]) )/UminusAlpha[i];
     }
     for (i=0;i<(*n);i++) r5[i] = r1[i] + r3[i] - r4[i];
 
     if (*p)
     {
-        LRQPSolve( n, m, &one, method, Q, D, r5, r, M, pivN, buffMx1, P, Beta, Lambda );
+        LRQPSolve( n, m, &intone, method, Q, D, r5, r, M, pivN, buffMx1, P, Beta, Lambda );
         VectorVectorCopy( buffPx1, r2, p );
-        MatrixVectorMult( &pone, A, 1, r, &mone, buffPx1, n, p );
-        MatrixMatrixMult( &pone, A, 1, R, 0, &zero, buffPxP, n, p, n, p, p, p );
+        MatrixVectorMult( &pone, A, &intone, r, &mone, buffPx1, n, p );
+        MatrixMatrixMult( &pone, A, &intone, R, &intzero, &zero, buffPxP, n, p, n, p, p, p );
         MatrixCholFactorize( buffPxP, p, &info );
-        MatrixCholSolve( buffPxP, p, buffPx1, &one, &info);
+        MatrixCholSolve( buffPxP, p, buffPx1, &intone, &info);
         VectorVectorCopy( dbeta, buffPx1, p );
         VectorVectorCopy( dalpha, r , n);
-        MatrixVectorMult( &mone, R, 0, dbeta, &pone, dalpha, n, p );
+        MatrixVectorMult( &mone, R, &intzero, dbeta, &pone, dalpha, n, p );
     }
     else
     {
-        LRQPSolve( n, m, &one, method, Q, D, r5, dalpha, M, pivN, buffMx1, P, Beta, Lambda );
+        LRQPSolve( n, m, &intone, method, Q, D, r5, dalpha, M, pivN, buffMx1, P, Beta, Lambda );
     }
     for (i=0;i<(*n);i++) dzeta[i] = r3[i] - (ZetaOnAlpha[i] * dalpha[i]);
     for (i=0;i<(*n);i++) dxi[i]   = r4[i] + (XiOnUminusAlpha[i] * dalpha[i]);
@@ -719,9 +732,6 @@ void LowRankQP( int *n, int *m, int *p, int* method, int* verbose, int* niter,
 {
     int i;
     
-    long int start;
-    long int finish;
-
     /* Iteration Display variables */
     double mult = 0.0;
     double prim = 0.0;
@@ -769,7 +779,15 @@ void LowRankQP( int *n, int *m, int *p, int* method, int* verbose, int* niter,
     double *Lambda;
     double *LambdaTemp;
     double *T;
-
+    
+    int pred = 1;
+    int corr = 2;
+    
+    int lu = 1;
+    int chol = 2;
+    int smw = 3;
+    int pfcf = 4;
+    
     /* Vectors to be created if p!=0 */
     if (*p)
     {
@@ -781,20 +799,20 @@ void LowRankQP( int *n, int *m, int *p, int* method, int* verbose, int* niter,
         buffPx1 = (double *) calloc( (*p), sizeof(double) );
     }
 
-    if ((*method==LU)||(*method==CHOL))
+    if (((*method)==lu)||((*method)==chol))
     {
         M    = (double *) calloc( (*n)*(*n), sizeof(double) );
         pivN = (int *) calloc( *n, sizeof(int) );
     }
     else
     {
-        if (*method==SMW)
+        if ((*method)==smw)
         {
             buffNxM  = (double *) calloc( (*n)*(*m), sizeof(double) );
             M        = (double *) calloc( (*m)*(*m), sizeof(double) );
             buffMx1  = (double *) calloc( (*m), sizeof(double) );
         }
-        else if (*method==PFCF)
+        else if ((*method)==pfcf)
         {
             P          = (double *) calloc( (*n)*(*m), sizeof(double) );
             Beta       = (double *) calloc( (*n)*(*m), sizeof(double) );
@@ -808,36 +826,46 @@ void LowRankQP( int *n, int *m, int *p, int* method, int* verbose, int* niter,
     if ( *verbose ) LRQPHeader();
     LRQPInitPoint( n, m, p, Q, c, A, b, u, alpha, beta, xi, zeta, w, r1 );
 
+
+	
     for (i=0;i<(*niter);i++)
     {
-        /* start = clock(); */
+        // start = clock();  
+        
         LRQPCalcStats( n, m, p, Q, c, A, b, u, alpha, beta, xi, zeta, dalpha,
             dbeta, dxi, dzeta, UminusAlpha, XiOnUminusAlpha, ZetaOnAlpha, w, r1,
             r2, D, &prim, &dual, &comp, &gap, &term, &mult, &t );
-        /* finish = clock();
-        TimeIpmCalcStats += (finish - start)/CLK_TCK; */
+         
+        // finish = clock();
+        // TimeIpmCalcStats += (finish - start)/CLK_TCK;  
 
-        if ( *verbose ) LRQPDisplay( i+1, &prim, &dual, &comp, &gap, &term  );
+        if ( *verbose ) LRQPDisplay( &i, &prim, &dual, &comp, &gap, &term  );
         if ( term < EPSTERM ) break;
 
+
         LRQPFactorize( n, m, method, Q, D, M, pivN, buffNxM, P, Beta, Lambda,
             LambdaTemp, T );
-
+            
+ 
         LRQPCalcDx( n, m, p, method, Q, c, A, b, u, alpha, beta, xi, zeta,
             dalpha, dbeta, dxi, dzeta, UminusAlpha, ZetaOnAlpha, 
             XiOnUminusAlpha, buffMxP, buffMx1, buffPxP, buffPx1, pivN, R, r, r1,
-            r2, r3, r4, r5, D, M, &t, P, Beta, Lambda, LambdaTemp, T, PRED);
+            r2, r3, r4, r5, D, M, &t, P, Beta, Lambda, LambdaTemp, T, &pred);
 
+		
+			
         LRQPCalcDx( n, m, p, method, Q, c, A, b, u, alpha, beta, xi, zeta,
             dalpha, dbeta, dxi, dzeta, UminusAlpha, ZetaOnAlpha,
             XiOnUminusAlpha, buffMxP, buffMx1, buffPxP, buffPx1, pivN, R, r, r1,
-            r2, r3, r4, r5, D, M, &t, P, Beta, Lambda, LambdaTemp, T, CORR);
-
+            r2, r3, r4, r5, D, M, &t, P, Beta, Lambda, LambdaTemp, T, &corr);
+          
         LRQPStep( n, p, alpha, beta, xi, zeta, dalpha, dbeta, dxi, dzeta,
-            UminusAlpha, &mult );
+            UminusAlpha, &mult );  
     }
     
-    LRQPSummary( i, *niter, *method, *n, *m, &prim, &dual, &comp, &gap, &term );
+    LRQPSummary( &i, niter, method, n, m, &prim, &dual, &comp, &gap, &term );
+    
+   
 
     /* Free Memory */
     free(dalpha);      free(dxi);             free(dzeta);
@@ -855,20 +883,20 @@ void LowRankQP( int *n, int *m, int *p, int* method, int* verbose, int* niter,
         free( buffPx1 );
     }
 
-    if ((*method==LU)||(*method==CHOL))
+    if (((*method)==lu)||((*method)==chol))
     {
         free( M );
         free( pivN );
     }
     else
     {
-        if (*method==SMW)
+        if ((*method)==smw)
         {
             free( buffMx1 );
             free( buffNxM );
             free( M  );
         }
-        else if (*method==PFCF)
+        else if ((*method)==pfcf)
         {
             free( P );
             free( Beta );
